@@ -11,6 +11,7 @@ from werkzeug import secure_filename
 from base64 import b64decode
 from wtforms.fields import TextField
 from flask.ext.admin.form import RenderTemplateWidget
+from shelf.security.mixin import LoginMixin
 
 _unset_value = object()
 
@@ -155,7 +156,7 @@ class PictureField(TextField):
             self.data.set_path(valuelist[0])
 
 
-class FileAdmin(fileadmin.FileAdmin):
+class FileAdmin(LoginMixin, fileadmin.FileAdmin):
     list_template = "shelf-library-list.html"
     icon_list_template = "shelf-library-icon-list.html"
     upload_template = "shelf-library-upload.html"
